@@ -7,7 +7,7 @@ import sys
 import logging
 from subprocess import run
 from importlib_resources import read_text
-from distutils.version import StrictVersion
+from packaging.version import parse as version_parse
 
 import redis
 from prompt_toolkit.shortcuts import clear
@@ -55,25 +55,35 @@ class Client:
 
     def __init__(
         self,
-        host=None,
-        port=None,
+        host="127.0.0.1",
+        port=6379,
         db=0,
         password=None,
         path=None,
         scheme="redis",
         username=None,
         client_name=None,
+        prompt=None,
     ):
         self.host = host
         self.port = port
         self.db = db
         self.path = path
-        # FIXME username is not using...
         self.username = username
         self.client_name = client_name
         self.scheme = scheme
         self.password = password
 
+        # cli args --prompt will overwrite the prompt in iredisrc config file
+        self.prompt = ""
+        if config.prompt:
+            self.prompt = config.prompt
+        if prompt:
+            self.prompt = prompt
+
+        self.client_id = None
+        self.client_addr = None
+
         self.build_connection()
 
         # all command upper case
@@ -93,6 +103,13 @@ class Client:
         else:
             config.no_version_reason = "--no-info flag activated"
 
+        if self.prompt and "client_addr" in self.prompt:
+            self.client_addr = ":".join(
+                str(x) for x in self.connection._sock.getsockname()
+            )
+        if self.prompt and "client_id" in self.prompt:
+            self.client_id = str(self.execute("CLIENT ID"))
+
         if config.version and re.match(r"([\d\.]+)", config.version):
             self.auth_compat(config.version)
 
@@ -131,6 +148,11 @@ class Client:
                 "socket_keepalive": config.socket_keepalive,
                 "client_name": client_name,
             }
+
+            # if username is set without setting paswword, password will be ignored
+            if password:
+                connection_kwargs["username"] = username
+
             if scheme == "rediss":
                 connection_class = SSLConnection
             else:
@@ -141,6 +163,7 @@ class Client:
                 "password": password,
                 "path": path,
                 "client_name": client_name,
+                "username": username,
             }
             connection_class = UnixDomainSocketConnection
 
@@ -150,15 +173,18 @@ class Client:
             connection_kwargs["encoding_errors"] = "replace"
 
         logger.debug(
-            f"connection_class={connection_class}, connection_kwargs={connection_kwargs}"
+            f"connection_class={connection_class},"
+            f" connection_kwargs={connection_kwargs}"
         )
 
         return connection_class(**connection_kwargs)
 
     def auth_compat(self, redis_version: str):
-        with_username = StrictVersion(redis_version) >= StrictVersion("6.0.0")
+        with_username = version_parse(redis_version) >= version_parse("6.0.0")
         if with_username:
             command2syntax["AUTH"] = "command_usernamex_password"
+        else:
+            command2syntax["AUTH"] = "command_password"
 
     def set_default_pager(self, config):
         configured_pager = config.pager
@@ -184,13 +210,23 @@ class Client:
     def get_server_info(self):
         # safe to decode Redis's INFO response
         info_resp = nativestr(self.execute("INFO"))
-        version = re.findall(r"^redis_version:([\d\.]+)\r\n", info_resp, re.MULTILINE)[
-            0
-        ]
+        version = re.findall(r"redis_version:(.+)\r\n", info_resp)[0]
         logger.debug(f"[Redis Version] {version}")
         config.version = version
 
     def __str__(self):
+        if self.prompt:  # not None and not empty
+            return self.prompt.format(
+                client_name=self.client_name,
+                db=self.db,
+                host=self.host,
+                path=self.path,
+                port=self.port,
+                username=self.username,
+                client_addr=self.client_addr,
+                client_id=self.client_id,
+            )
+
         if self.scheme == "unix":
             prompt = f"redis {self.path}"
         else:
@@ -198,7 +234,8 @@ class Client:
 
         if self.db:
             prompt = f"{prompt}[{self.db}]"
-        return prompt
+
+        return f"{prompt}> "
 
     def client_execute_command(self, command_name, *args):
         command = command_name.upper()
@@ -222,9 +259,10 @@ class Client:
         Here we retry once for ConnectionError.
         """
         logger.info(
-            f"execute by connection: connection={connection}, name={command_name}, {args}, {options}"
+            f"execute by connection: connection={connection}, name={command_name},"
+            f" {args}, {options}"
         )
-        retry_times = config.retry_times  # FIXME configureable
+        retry_times = config.retry_times  # FIXME configurable
         last_error = None
         need_refresh_connection = False
 
@@ -248,7 +286,7 @@ class Client:
                 last_error = e
                 retry_times -= 1
                 need_refresh_connection = True
-            except (ResponseError) as e:
+            except ResponseError as e:
                 response_message = str(e)
                 if response_message.startswith("MOVED"):
                     return self.reissue_with_redirect(
@@ -487,7 +525,7 @@ class Client:
         """
         if command_name.upper() == "HELLO":
             raise NotSupport("IRedis currently not support RESP3, sorry about that.")
-        # TRANSATION state chage
+        # TRANSACTION state change
         if command_name.upper() in ["EXEC", "DISCARD"]:
             logger.debug(f"[After hook] Command is {command_name}, unset transaction.")
             config.transaction = False
@@ -527,25 +565,25 @@ class Client:
         rendered_detail = markdown.render(doc)
         summary_dict = commands_summary[command_summary_name]
 
-        avaiable_version = summary_dict.get("since", "?")
+        available_version = summary_dict.get("since", "?")
         server_version = config.version
         # FIXME anything strange with single quotes?
         logger.debug(f"[--version--] '{server_version}'")
         try:
-            is_avaiable = StrictVersion(server_version) > StrictVersion(
-                avaiable_version
+            is_available = version_parse(server_version) > version_parse(
+                available_version
             )
         except Exception as e:
             logger.exception(e)
-            is_avaiable = None
+            is_available = None
 
-        if is_avaiable:
-            avaiable_text = f"(Avaiable on your redis-server: {server_version})"
-        elif is_avaiable is False:
-            avaiable_text = f"(Not avaiable on your redis-server: {server_version})"
+        if is_available:
+            available_text = f"(Available on your redis-server: {server_version})"
+        elif is_available is False:
+            available_text = f"(Not available on your redis-server: {server_version})"
         else:
-            avaiable_text = ""
-        since_text = f"{avaiable_version} {avaiable_text}"
+            available_text = ""
+        since_text = f"{available_version} {available_text}"
 
         summary = [
             ("", "\n"),
@@ -658,7 +696,7 @@ class Client:
             yield FormattedText([("class:dockey", "XINFO: ")])
             yield renders.OutputRender.render_list(xinfo)
 
-        # incase the result is too long, we yield only once so the outputer
+        # in case the result is too long, we yield only once so the outputer
         # can pager it.
         peek_response = []
         key_type = nativestr(self.execute("type", key))
@@ -670,7 +708,7 @@ class Client:
 
         # use `memory usage` to get memory, this command available from redis4.0
         mem = ""
-        if config.version and StrictVersion(config.version) >= StrictVersion("4.0.0"):
+        if config.version and version_parse(config.version) >= version_parse("4.0.0"):
             memory_usage_value = str(self.execute("memory usage", key))
             mem = f"  mem: {memory_usage_value} bytes"
 
